@@ -36,6 +36,12 @@ static bool findBackwardInBlock (const QTextBlock &block, const QString &str, in
     QString text = block.text();
     text.replace (QChar::Nbsp, QLatin1Char (' '));
 
+    /* WARNING: QString::lastIndexOf() returns -1 if the position, from which the
+                backward search is done, is the position of the block's last cursor.
+                The following workaround compensates for this illogical behavior. */
+    if (offset > 0 && offset == text.length())
+        -- offset;
+
     int idx = -1;
     while (offset >= 0 && offset <= text.length())
     {
@@ -61,7 +67,7 @@ static bool findBackwardInBlock (const QTextBlock &block, const QString &str, in
     return false;
 }
 
-static bool findBackward (const QTextDocument *txtdoc, const QString str,
+static bool findBackward (const QTextDocument *txtdoc, const QString &str,
                           QTextCursor &cursor, QTextDocument::FindFlags flags)
 {
     if (!str.isEmpty() && !cursor.isNull())
@@ -77,7 +83,7 @@ static bool findBackward (const QTextDocument *txtdoc, const QString str,
                 if (findBackwardInBlock (block, str, blockOffset, cursor, flags))
                     return true;
                 block = block.previous();
-                blockOffset = block.length() - 2; // newline is included in length()
+                blockOffset = block.length() - 1; // newline is included in QTextBlock::length()
             }
         }
     }
@@ -446,19 +452,18 @@ void FN::hlight() const
     if (!cw) return;
 
     TextEdit *textEdit = qobject_cast< TextEdit *>(cw);
-    QString txt = searchEntries_[textEdit];
+    const QString txt = searchEntries_[textEdit];
     if (txt.isEmpty()) return;
 
     QList<QTextEdit::ExtraSelection> extraSelections;
     /* prepend green highlights */
     extraSelections.append (greenSels_[textEdit]);
-    QColor yellow = QColor (Qt::yellow);
-    QColor black = QColor (Qt::black);
+    QColor yellow = qGray(fgColor_.rgb()) > 127 ? QColor (Qt::darkYellow) : QColor (Qt::yellow);
     QTextCursor found;
     /* first put a start cursor at the top left edge... */
     QPoint Point (0, 0);
     QTextCursor start = textEdit->cursorForPosition (Point);
-    /* ... them move it backward by the search text length */
+    /* ... then move it backward by the search text length */
     int startPos = start.position() - txt.length();
     if (startPos >= 0)
         start.setPosition (startPos);
@@ -476,21 +481,22 @@ void FN::hlight() const
         end.setPosition (endPos);
     QTextCursor visCur = start;
     visCur.setPosition (end.position(), QTextCursor::KeepAnchor);
-    QString str = visCur.selection().toPlainText(); // '\n' is included in this way
-    Qt::CaseSensitivity cs = Qt::CaseInsensitive;
-    if (ui->caseButton->isChecked()) cs = Qt::CaseSensitive;
-    while (str.contains (txt, cs) // don't waste time if the search text isn't visible
-           && !(found = finding (txt, start, searchFlags_)).isNull())
+    const QString str = visCur.selection().toPlainText(); // '\n' is included in this way
+    Qt::CaseSensitivity cs = ui->caseButton->isChecked() ? Qt::CaseSensitive : Qt::CaseInsensitive;
+    if (str.contains (txt, cs)) // don't waste time if the searched text isn't visible
     {
-        QTextEdit::ExtraSelection extra;
-        extra.format.setBackground (yellow);
-        extra.format.setFontUnderline (true);
-        extra.format.setUnderlineStyle (QTextCharFormat::WaveUnderline);
-        extra.format.setUnderlineColor (black);
-        extra.cursor = found;
-        extraSelections.append (extra);
-        start.setPosition (found.position());
-        if (textEdit->cursorRect (start).top() >= h) break;
+        while (!(found = finding (txt, start, searchFlags_)).isNull())
+        {
+            QTextEdit::ExtraSelection extra;
+            extra.format.setBackground (yellow);
+            extra.format.setFontUnderline (true);
+            extra.format.setUnderlineStyle (QTextCharFormat::WaveUnderline);
+            extra.format.setUnderlineColor (fgColor_);
+            extra.cursor = found;
+            extraSelections.append (extra);
+            start.setPosition (found.position());
+            if (textEdit->cursorRect (start).top() >= h) break;
+        }
     }
 
     textEdit->setExtraSelections (extraSelections);
@@ -503,7 +509,7 @@ void FN::rehighlight (TextEdit *textEdit)
 }
 /*************************/
 void FN::reallySetSearchFlags (bool h)
-{   
+{
     searchFlags_ = QTextDocument::FindFlags();
     if (ui->wholeButton->isChecked())
         searchFlags_ = QTextDocument::FindWholeWords;
