@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2016-2019 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2016-2020 <tsujan2000@gmail.com>
  *
  * FeatherNotes is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -39,10 +39,11 @@ class FN : public QMainWindow
     Q_OBJECT
 
 public:
-    explicit FN (const QString& message, QWidget *parent = nullptr);
+    explicit FN (const QStringList& message, QWidget *parent = nullptr);
     ~FN();
 
     void writeGeometryConfig();
+    void rememberLastOpenedFile();
     void writeConfig();
 
     bool isSizeRem() const {
@@ -77,6 +78,13 @@ public:
         splitterSizes_ = sizes;
     }
 
+    QSize getPrefSize() const {
+        return prefSize_;
+    }
+    void setPrefSize (const QSize &s) {
+        prefSize_ = s;
+    }
+
     bool isPositionRem() const {
         return remPosition_;
     }
@@ -152,6 +160,20 @@ public:
         autoBracket_ = yes;
     }
 
+    bool hasAutoReplace() const {
+        return autoReplace_;
+    }
+    void autoReplace (bool yes) {
+        autoReplace_ = yes;
+    }
+
+    QString getDateFormat() const {
+        return dateFormat_;
+    }
+    void setDateFormat (const QString &format) {
+        dateFormat_ = format;
+    }
+
     int getAutoSave() const {
         return autoSave_;
     }
@@ -159,10 +181,42 @@ public:
         autoSave_ = interval;
     }
 
-    bool isScrollJumpWorkaroundEnabled() const {
-        return scrollJumpWorkaround_;
+    void updateCustomizableShortcuts();
+
+    QHash<QString, QString> customShortcutActions() const {
+        return customActions_;
     }
-    void enableScrollJumpWorkaround (bool enable);
+    void setActionShortcut (const QString &action, const QString &shortcut) {
+        customActions_.insert (action, shortcut);
+    }
+    void removeShortcut (const QString &action) {
+        customActions_.remove (action);
+        uncustomizedActions_ << action;
+    }
+
+    QHash<QAction*, QKeySequence> defaultShortcuts() const {
+        return defaultShortcuts_;
+    }
+
+    QStringList reservedShortcuts() const {
+        return reservedShortcuts_;
+    }
+
+    bool openLastFile() const {
+        return openLastFile_;
+    }
+    void setOpenLastFile (bool openLastFile) {
+        openLastFile_ = openLastFile;
+    }
+
+#ifdef HAS_HUNSPELL
+    QString getDictPath() const {
+        return dictPath_;
+    }
+    void setDictPath (const QString& dictPath) {
+        dictPath_ = dictPath;
+    }
+#endif
 
 private slots:
     bool close();
@@ -187,6 +241,7 @@ private slots:
     void pasteHTML();
     void deleteText();
     void selectAllText();
+    void insertDate();
     void setCursorInsideSelection (bool sel);
     void txtContextMenu (const QPoint &p);
     void copyLink();
@@ -237,6 +292,7 @@ private slots:
     void toggleStatusBar();
     void textFontDialog();
     void nodeFontDialog();
+    void docColorDialog();
     void toggleWrapping();
     void toggleIndent();
     void prefDialog();
@@ -273,9 +329,13 @@ private slots:
     void showHelpDialog();
     void closeTagsDialog();
 
+#ifdef HAS_HUNSPELL
+    void checkSpelling();
+#endif
+
 private:
     void enableActions (bool enable);
-    void fileOpen (const QString &filePath);
+    void fileOpen (const QString &filePath, bool startup = false);
     bool fileSave (const QString &filePath);
     void createTrayIcon();
     void closeEvent (QCloseEvent *event);
@@ -288,7 +348,7 @@ private:
     bool unSaved (bool modified);
     TextEdit *newWidget();
     void mergeFormatOnWordOrSelection (const QTextCharFormat &format);
-    void setNewFont (DomItem *item, QTextCharFormat &fmt);
+    void setNewFont (DomItem *item, const QTextCharFormat &fmt);
     QTextCursor finding (const QString& str,
                          const QTextCursor& start,
                          QTextDocument::FindFlags flags) const;
@@ -296,12 +356,19 @@ private:
     void reallySetSearchFlags (bool h);
     void findInNames();
     bool isImageSelected();
+    void readShortcuts();
+    QString validatedShortcut (const QVariant v, bool *isValid);
     void readAndApplyConfig (bool startup = true);
     QString nodeAddress (QModelIndex index);
     bool isPswrdCorrect();
     void dragMoveEvent (QDragMoveEvent *event);
     void dragEnterEvent (QDragEnterEvent *event);
     void dropEvent (QDropEvent *event);
+    bool event (QEvent *event);
+
+#ifdef HAS_HUNSPELL
+    void spellingCheckingMsg (const QString &msg, bool hasInfo);
+#endif
 
     Ui::FN *ui;
     bool isX11_;
@@ -311,6 +378,7 @@ private:
     int trayCounter_; // Used when waiting for the system tray to be created at startup.
     int saveNeeded_;
     QFont defaultFont_, nodeFont_;
+    QColor bgColor_, fgColor_;
     QColor lastTxtColor_, lastBgColor_;
     DomModel *model_;
     QString xmlPath_;
@@ -323,7 +391,7 @@ private:
     bool searchingOtherNode_; // Needed when jumping to another node during search.
     bool rplOtherNode_; // Like above but for replacement.
     int replCount_; // Needed for counting replacements in all nodes.
-    QHash<TextEdit*,QList<QTextEdit::ExtraSelection> > greenSels_; // For replaced matches.
+    QHash<TextEdit*, QList<QTextEdit::ExtraSelection> > greenSels_; // For replaced matches.
     QString txtReplace_; // The replacing text.
     QModelIndexList tagsList_;
     QString linkAtPos_; // Text hyperlink at the right-click position.
@@ -340,17 +408,27 @@ private:
          smallToolbarIcons_,
          noToolbar_,
          noMenubar_,
-         autoBracket_;
+         autoBracket_,
+         autoReplace_,
+         openLastFile_,
+         treeViewDND_;
+    QString dateFormat_;
     int autoSave_;
     QPoint position_; // Excluding the window frame.
-    QSize winSize_, startSize_;
+    QSize winSize_, startSize_, prefSize_;
     //QList<int> splitterSizes_;
     QByteArray splitterSizes_;
     QTimer *timer_;
     QString pswrd_;
-    bool scrollJumpWorkaround_; // Should a workaround for Qt5's "scroll jump" bug be applied?
     bool underE_; // Is FeatherNotes running under Enlightenment?
     QSize EShift_; // The shift Enlightenment's panel creates (a bug?).
+    QHash<QString, QString> customActions_;
+    QHash<QAction*, QKeySequence> defaultShortcuts_;
+    QStringList uncustomizedActions_, reservedShortcuts_;
+
+#ifdef HAS_HUNSPELL
+    QString dictPath_;
+#endif
 };
 
 }
