@@ -19,6 +19,9 @@
 #define VSCROLLBAR_H
 
 #include <QScrollBar>
+#if (QT_VERSION == QT_VERSION_CHECK(5,14,0))
+#include <QWheelEvent>
+#endif
 
 namespace FeatherNotes {
 
@@ -37,6 +40,19 @@ private:
     int defaultWheelSpeed;
 };
 
+#if (QT_VERSION == QT_VERSION_CHECK(5,14,0))
+/* Workaround. */
+class HScrollBar : public QScrollBar
+{
+    Q_OBJECT
+public:
+    HScrollBar (QWidget *parent = nullptr) : QScrollBar (parent) {};
+
+protected:
+    void wheelEvent (QWheelEvent *event);
+};
+#endif
+
 }
 
 #endif // VSCROLLBAR_H
